@@ -68,7 +68,7 @@ def parse_config():
         sys.exit(0)
 
     check_and_ask(config)
-    print(f"Config {file} found at full path {os.path.abspath(file)}")
+    # print(f"Config {file} found at full path {os.path.abspath(file)}")
     # write the config file with the new values
     try:
         with open(file, "w") as config_file:
